==> google-cloud-sdk-268.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/googlecloudsdk/api_lib/events/trigger.py <==
# -*- coding: utf-8 -*- #
# Copyright 2019 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Wraps an Events Trigger message, making fields more convenient."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.run import k8s_object


# TODO(b/141719436): Don't hardcode v1alpha1 version
_SERVICE_API_VERSION = 'serving.knative.dev/v1alpha1'
_SERVICE_KIND = 'Service'

EVENT_TYPE_FIELD = 'type'
# k8s OwnerReference serialized to a json string
DEPENDENCY_ANNOTATION_FIELD = 'knative.dev/dependency'


class Trigger(k8s_object.KubernetesObject):
  """Wraps an Events Trigger message, making fields more convenient."""

  API_CATEGORY = 'eventing.knative.dev'
  KIND = 'Trigger'
  READY_CONDITION = 'Ready'
  TERMINAL_CONDITIONS = {
      READY_CONDITION,
  }

  @property
  def broker(self):
    return self._m.spec.broker

  @property
  def subscriber(self):
    return self._m.spec.subscriber.ref.name

  @subscriber.setter
  def subscriber(self, service_name):
    """Set the subscriber to a Cloud Run service."""
    self._m.spec.subscriber.ref.apiVersion = _SERVICE_API_VERSION
    self._m.spec.subscriber.ref.kind = _SERVICE_KIND
    self._m.spec.subscriber.ref.name = service_name

  @property
  def filter_attributes(self):
    return k8s_object.ListAsDictionaryWrapper(
        self._m.spec.filter.attributes.additionalProperties,
        self._messages.TriggerFilter.AttributesValue.AdditionalProperty,
        key_field='key',
        value_field='value')

==> google-cloud-sdk-269.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/googlecloudsdk/api_lib/events/trigger.py <==
# -*- coding: utf-8 -*- #
# Copyright 2019 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Wraps an Events Trigger message, making fields more convenient."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from apitools.base.protorpclite import protojson
from googlecloudsdk.api_lib.run import k8s_object


# TODO(b/141719436): Don't hardcode v1alpha1 version
_SERVICE_API_VERSION = 'serving.knative.dev/v1alpha1'
_SERVICE_KIND = 'Service'

EVENT_TYPE_FIELD = 'type'
# k8s OwnerReference serialized to a json string
DEPENDENCY_ANNOTATION_FIELD = 'knative.dev/dependency'
# Field placed on both the trigger and source (as a CEOverrdie) to link the
# resources so the trigger only consumes events from that source
SOURCE_TRIGGER_LINK_FIELD = 'knsourcetrigger'


class Trigger(k8s_object.KubernetesObject):
  """Wraps an Events Trigger message, making fields more convenient."""

  API_CATEGORY = 'eventing.knative.dev'
  KIND = 'Trigger'
  READY_CONDITION = 'Ready'
  TERMINAL_CONDITIONS = {
      READY_CONDITION,
  }
  FIELD_BLACKLIST = ['sourceAndType']

  @property
  def dependency(self):
    """The knative dependency annotation.

    Returns:
      ObjectReference of the dependency annotation if one exists, else None.
    """
    if DEPENDENCY_ANNOTATION_FIELD not in self.annotations:
      return None
    return protojson.decode_message(
        self._messages.ObjectReference,
        self.annotations[DEPENDENCY_ANNOTATION_FIELD])

  @dependency.setter
  def dependency(self, k8s_obj):
    """Set the knative dependency annotation by passing a k8s_object.KubernetesObject."""
    self.annotations[DEPENDENCY_ANNOTATION_FIELD] = protojson.encode_message(
        k8s_obj.AsObjectReference())

  @property
  def broker(self):
    return self._m.spec.broker

  @property
  def subscriber(self):
    return self._m.spec.subscriber.ref.name

  @subscriber.setter
  def subscriber(self, service_name):
    """Set the subscriber to a Cloud Run service."""
    self._m.spec.subscriber.ref.apiVersion = _SERVICE_API_VERSION
    self._m.spec.subscriber.ref.kind = _SERVICE_KIND
    self._m.spec.subscriber.ref.name = service_name

  @property
  def filter_attributes(self):
    return k8s_object.ListAsDictionaryWrapper(
        self._m.spec.filter.attributes.additionalProperties,
        self._messages.TriggerFilter.AttributesValue.AdditionalProperty,
        key_field='key',
        value_field='value')
